==> ruby-dcl_1.6.3.orig.tar.gz: ruby-dcl-1.6.3/misc1_randlib.c <==
/*
 * $Id: p_header,v 1.2 2011-02-23 17:47:10 koshiro Exp $
 */

#include <stdio.h>
#include "ruby.h"
#include "libtinyf2c.h"
#include "narray.h"

/* for compatibility with ruby 1.6 */
#ifndef StringValuePtr
#define StringValuePtr(s) STR2CSTR(s)
#endif

#define DFLT_SIZE 32

extern char    *dcl_obj2ccharary(VALUE, int, int);
extern integer *dcl_obj2cintegerary(VALUE);
extern real    *dcl_obj2crealary(VALUE);
extern complex *dcl_obj2ccomplexary(VALUE);
extern logical *dcl_obj2clogicalary(VALUE);

extern VALUE dcl_ccharary2obj(char *, int, int);
extern VALUE dcl_cintegerary2obj(integer *, int, int, int *);
extern VALUE dcl_crealary2obj(real *, int, int, int *);
extern VALUE dcl_ccomplexary2obj(complex *, int, char *);
extern VALUE dcl_clogicalary2obj(logical *, int, int, int *);

extern void dcl_freeccharary(char *);
extern void dcl_freecintegerary(integer *);
extern void dcl_freecrealary(real *);
extern void dcl_freeccomplexary(complex *);
extern void dcl_freeclogicalary(logical *);

/* for functions which return real */
/* fnclib */
extern real rd2r_(real *);
extern real rr2d_(real *);
extern real rexp_(real *, integer *, integer *);
extern real rfpi_(void);
extern real rmod_(real *, real *);
/* gnmlib */
extern real rgnlt_(real *);
extern real rgnle_(real *);
extern real rgngt_(real *);
extern real rgnge_(real *);
/* rfalib */
extern real rmax_(real *, integer *, integer *);
extern real rmin_(real *, integer *, integer *);
extern real rsum_(real *, integer *, integer *);
extern real rave_(real *, integer *, integer *);
extern real rvar_(real *, integer *, integer *);
extern real rstd_(real *, integer *, integer *);
extern real rrms_(real *, integer *, integer *);
extern real ramp_(real *, integer *, integer *);
/* rfblib */
extern real rprd_(real *, real *, integer *, integer *, integer *);
extern real rcov_(real *, real *, integer *, integer *, integer *);
extern real rcor_(real *, real *, integer *, integer *, integer *);


extern VALUE mDCL;

static VALUE
dcl_rngu1(obj, iseed)
    VALUE obj, iseed;
{
    integer io_iseed;
    real o_rtn_val;
    VALUE rtn_val;

    if ((TYPE(iseed) != T_BIGNUM) || (TYPE(iseed) != T_FIXNUM)) {
      iseed = rb_funcall(iseed, rb_intern("to_i"), 0);
    }

    io_iseed = NUM2INT(iseed);


    o_rtn_val = rngu1_(&io_iseed);

    rtn_val = rb_float_new((double)o_rtn_val);


    return rtn_val;

}

static VALUE
dcl_rngu2(obj, iseed)
    VALUE obj, iseed;
{
    integer io_iseed;
    real o_rtn_val;
    VALUE rtn_val;

    if ((TYPE(iseed) != T_BIGNUM) || (TYPE(iseed) != T_FIXNUM)) {
      iseed = rb_funcall(iseed, rb_intern("to_i"), 0);
    }

    io_iseed = NUM2INT(iseed);


    o_rtn_val = rngu2_(&io_iseed);

    rtn_val = rb_float_new((double)o_rtn_val);


    return rtn_val;

}

static VALUE
dcl_rngu3(obj, iseed)
    VALUE obj, iseed;
{
    integer io_iseed;
    real o_rtn_val;
    VALUE rtn_val;

    if ((TYPE(iseed) != T_BIGNUM) || (TYPE(iseed) != T_FIXNUM)) {
      iseed = rb_funcall(iseed, rb_intern("to_i"), 0);
    }

    io_iseed = NUM2INT(iseed);


    o_rtn_val = rngu3_(&io_iseed);

    rtn_val = rb_float_new((double)o_rtn_val);


    return rtn_val;

}
void
init_misc1_randlib(mDCL)
VALUE mDCL;
{
    rb_define_module_function(mDCL, "rngu1", dcl_rngu1, 1);
    rb_define_module_function(mDCL, "rngu2", dcl_rngu2, 1);
    rb_define_module_function(mDCL, "rngu3", dcl_rngu3, 1);
}

==> ruby-dcl_1.7.0.orig.tar.gz: ruby-dcl-1.7.0/misc1_randlib.c <==
/*
 * $Id: p_header,v 1.2 2011-02-23 17:47:10 koshiro Exp $
 */

#include <stdio.h>
#include "ruby.h"
#include "libtinyf2c.h"
#include "narray.h"

/* for compatibility with ruby 1.6 */
#ifndef StringValuePtr
#define StringValuePtr(s) STR2CSTR(s)
#endif

#define DFLT_SIZE 32

extern char    *dcl_obj2ccharary(VALUE, int, int);
extern integer *dcl_obj2cintegerary(VALUE);
extern real    *dcl_obj2crealary(VALUE);
extern complex *dcl_obj2ccomplexary(VALUE);
extern logical *dcl_obj2clogicalary(VALUE);

extern VALUE dcl_ccharary2obj(char *, int, int);
extern VALUE dcl_cintegerary2obj(integer *, int, int, int *);
extern VALUE dcl_crealary2obj(real *, int, int, int *);
extern VALUE dcl_ccomplexary2obj(complex *, int, char *);
extern VALUE dcl_clogicalary2obj(logical *, int, int, int *);

extern void dcl_freeccharary(char *);
extern void dcl_freecintegerary(integer *);
extern void dcl_freecrealary(real *);
extern void dcl_freeccomplexary(complex *);
extern void dcl_freeclogicalary(logical *);

/* for functions which return real */
/* fnclib */
extern real rd2r_(real *);
extern real rr2d_(real *);
extern real rexp_(real *, integer *, integer *);
extern real rfpi_(void);
extern real rmod_(real *, real *);
/* gnmlib */
extern real rgnlt_(real *);
extern real rgnle_(real *);
extern real rgngt_(real *);
extern real rgnge_(real *);
/* rfalib */
extern real rmax_(real *, integer *, integer *);
extern real rmin_(real *, integer *, integer *);
extern real rsum_(real *, integer *, integer *);
extern real rave_(real *, integer *, integer *);
extern real rvar_(real *, integer *, integer *);
extern real rstd_(real *, integer *, integer *);
extern real rrms_(real *, integer *, integer *);
extern real ramp_(real *, integer *, integer *);
/* rfblib */
extern real rprd_(real *, real *, integer *, integer *, integer *);
extern real rcov_(real *, real *, integer *, integer *, integer *);
extern real rcor_(real *, real *, integer *, integer *, integer *);


extern VALUE mDCL;

#if DCLVER >= 544

static VALUE
dcl_rngu0(obj, iseed)
    VALUE obj, iseed;
{
    integer io_iseed;
    real o_rtn_val;
    VALUE rtn_val;

    if ((TYPE(iseed) != T_BIGNUM) || (TYPE(iseed) != T_FIXNUM)) {
      iseed = rb_funcall(iseed, rb_intern("to_i"), 0);
    }

    io_iseed = NUM2INT(iseed);


    o_rtn_val = rngu0_(&io_iseed);

    rtn_val = rb_float_new((double)o_rtn_val);


    return rtn_val;

}

#endif

static VALUE
dcl_rngu1(obj, iseed)
    VALUE obj, iseed;
{
    integer io_iseed;
    real o_rtn_val;
    VALUE rtn_val;

    if ((TYPE(iseed) != T_BIGNUM) || (TYPE(iseed) != T_FIXNUM)) {
      iseed = rb_funcall(iseed, rb_intern("to_i"), 0);
    }

    io_iseed = NUM2INT(iseed);


    o_rtn_val = rngu1_(&io_iseed);

    rtn_val = rb_float_new((double)o_rtn_val);


    return rtn_val;

}

static VALUE
dcl_rngu2(obj, iseed)
    VALUE obj, iseed;
{
    integer io_iseed;
    real o_rtn_val;
    VALUE rtn_val;

    if ((TYPE(iseed) != T_BIGNUM) || (TYPE(iseed) != T_FIXNUM)) {
      iseed = rb_funcall(iseed, rb_intern("to_i"), 0);
    }

    io_iseed = NUM2INT(iseed);


    o_rtn_val = rngu2_(&io_iseed);

    rtn_val = rb_float_new((double)o_rtn_val);


    return rtn_val;

}

#if DCLVER < 544

static VALUE
dcl_rngu3(obj, iseed)
    VALUE obj, iseed;
{
    integer io_iseed;
    real o_rtn_val;
    VALUE rtn_val;

    if ((TYPE(iseed) != T_BIGNUM) || (TYPE(iseed) != T_FIXNUM)) {
      iseed = rb_funcall(iseed, rb_intern("to_i"), 0);
    }

    io_iseed = NUM2INT(iseed);


    o_rtn_val = rngu3_(&io_iseed);

    rtn_val = rb_float_new((double)o_rtn_val);


    return rtn_val;

}

#endif
void
init_misc1_randlib(mDCL)
VALUE mDCL;
{
#if DCLVER >= 544
    rb_define_module_function(mDCL, "rngu0", dcl_rngu0, 1);
#endif
    rb_define_module_function(mDCL, "rngu1", dcl_rngu1, 1);
    rb_define_module_function(mDCL, "rngu2", dcl_rngu2, 1);
#if DCLVER < 544
    rb_define_module_function(mDCL, "rngu3", dcl_rngu3, 1);
#endif
}
